
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/service/hlo_profile_printer_data.proto', package='xla', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n>tensorflow/compiler/xla/service/hlo_profile_printer_data.proto\x12\x03xla"\xeb\x04\n\x15HloProfilePrinterData\x12H\n\x11computation_infos\x18\x01 \x03(\x0b2-.xla.HloProfilePrinterData.HloComputationInfo\x12\x1d\n\x15profile_counters_size\x18\x02 \x01(\x03\x12C\n\rextra_metrics\x18\x03 \x03(\x0b2,.xla.HloProfilePrinterData.ExtraMetricsEntry\x12\x19\n\x11entry_computation\x18\x04 \x01(\t\x1a\xcd\x01\n\x12HloInstructionInfo\x12\x11\n\tlong_name\x18\x01 \x01(\t\x12\x12\n\nshort_name\x18\x02 \x01(\t\x12\x10\n\x08category\x18\x03 \x01(\t\x12\x12\n\nflop_count\x18\x04 \x01(\x02\x12\x1c\n\x14transcendental_count\x18\x05 \x01(\x02\x12\x16\n\x0ebytes_accessed\x18\t \x01(\x03\x12\x17\n\x0foptimal_seconds\x18\x07 \x01(\x02\x12\x15\n\rprofile_index\x18\x08 \x01(\x03J\x04\x08\x06\x10\x07\x1a\x83\x01\n\x12HloComputationInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rprofile_index\x18\x02 \x01(\x03\x12H\n\x11instruction_infos\x18\x03 \x03(\x0b2-.xla.HloProfilePrinterData.HloInstructionInfo\x1a3\n\x11ExtraMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x028\x01B\x03\xf8\x01\x01b\x06proto3')
_HLOPROFILEPRINTERDATA_HLOINSTRUCTIONINFO = _descriptor.Descriptor(name='HloInstructionInfo', full_name='xla.HloProfilePrinterData.HloInstructionInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='long_name', full_name='xla.HloProfilePrinterData.HloInstructionInfo.long_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='short_name', full_name='xla.HloProfilePrinterData.HloInstructionInfo.short_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='category', full_name='xla.HloProfilePrinterData.HloInstructionInfo.category', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='flop_count', full_name='xla.HloProfilePrinterData.HloInstructionInfo.flop_count', index=3, number=4, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transcendental_count', full_name='xla.HloProfilePrinterData.HloInstructionInfo.transcendental_count', index=4, number=5, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bytes_accessed', full_name='xla.HloProfilePrinterData.HloInstructionInfo.bytes_accessed', index=5, number=9, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='optimal_seconds', full_name='xla.HloProfilePrinterData.HloInstructionInfo.optimal_seconds', index=6, number=7, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_index', full_name='xla.HloProfilePrinterData.HloInstructionInfo.profile_index', index=7, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=299, serialized_end=504)
_HLOPROFILEPRINTERDATA_HLOCOMPUTATIONINFO = _descriptor.Descriptor(name='HloComputationInfo', full_name='xla.HloProfilePrinterData.HloComputationInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='xla.HloProfilePrinterData.HloComputationInfo.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_index', full_name='xla.HloProfilePrinterData.HloComputationInfo.profile_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='instruction_infos', full_name='xla.HloProfilePrinterData.HloComputationInfo.instruction_infos', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=507, serialized_end=638)
_HLOPROFILEPRINTERDATA_EXTRAMETRICSENTRY = _descriptor.Descriptor(name='ExtraMetricsEntry', full_name='xla.HloProfilePrinterData.ExtraMetricsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='xla.HloProfilePrinterData.ExtraMetricsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='xla.HloProfilePrinterData.ExtraMetricsEntry.value', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=640, serialized_end=691)
_HLOPROFILEPRINTERDATA = _descriptor.Descriptor(name='HloProfilePrinterData', full_name='xla.HloProfilePrinterData', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='computation_infos', full_name='xla.HloProfilePrinterData.computation_infos', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_counters_size', full_name='xla.HloProfilePrinterData.profile_counters_size', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extra_metrics', full_name='xla.HloProfilePrinterData.extra_metrics', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='entry_computation', full_name='xla.HloProfilePrinterData.entry_computation', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_HLOPROFILEPRINTERDATA_HLOINSTRUCTIONINFO, _HLOPROFILEPRINTERDATA_HLOCOMPUTATIONINFO, _HLOPROFILEPRINTERDATA_EXTRAMETRICSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=72, serialized_end=691)
_HLOPROFILEPRINTERDATA_HLOINSTRUCTIONINFO.containing_type = _HLOPROFILEPRINTERDATA
_HLOPROFILEPRINTERDATA_HLOCOMPUTATIONINFO.fields_by_name['instruction_infos'].message_type = _HLOPROFILEPRINTERDATA_HLOINSTRUCTIONINFO
_HLOPROFILEPRINTERDATA_HLOCOMPUTATIONINFO.containing_type = _HLOPROFILEPRINTERDATA
_HLOPROFILEPRINTERDATA_EXTRAMETRICSENTRY.containing_type = _HLOPROFILEPRINTERDATA
_HLOPROFILEPRINTERDATA.fields_by_name['computation_infos'].message_type = _HLOPROFILEPRINTERDATA_HLOCOMPUTATIONINFO
_HLOPROFILEPRINTERDATA.fields_by_name['extra_metrics'].message_type = _HLOPROFILEPRINTERDATA_EXTRAMETRICSENTRY
DESCRIPTOR.message_types_by_name['HloProfilePrinterData'] = _HLOPROFILEPRINTERDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
HloProfilePrinterData = _reflection.GeneratedProtocolMessageType('HloProfilePrinterData', (_message.Message,), {'HloInstructionInfo': _reflection.GeneratedProtocolMessageType('HloInstructionInfo', (_message.Message,), {'DESCRIPTOR': _HLOPROFILEPRINTERDATA_HLOINSTRUCTIONINFO, '__module__': 'tensorflow.compiler.xla.service.hlo_profile_printer_data_pb2'}), 'HloComputationInfo': _reflection.GeneratedProtocolMessageType('HloComputationInfo', (_message.Message,), {'DESCRIPTOR': _HLOPROFILEPRINTERDATA_HLOCOMPUTATIONINFO, '__module__': 'tensorflow.compiler.xla.service.hlo_profile_printer_data_pb2'}), 'ExtraMetricsEntry': _reflection.GeneratedProtocolMessageType('ExtraMetricsEntry', (_message.Message,), {'DESCRIPTOR': _HLOPROFILEPRINTERDATA_EXTRAMETRICSENTRY, '__module__': 'tensorflow.compiler.xla.service.hlo_profile_printer_data_pb2'}), 'DESCRIPTOR': _HLOPROFILEPRINTERDATA, '__module__': 'tensorflow.compiler.xla.service.hlo_profile_printer_data_pb2'})
_sym_db.RegisterMessage(HloProfilePrinterData)
_sym_db.RegisterMessage(HloProfilePrinterData.HloInstructionInfo)
_sym_db.RegisterMessage(HloProfilePrinterData.HloComputationInfo)
_sym_db.RegisterMessage(HloProfilePrinterData.ExtraMetricsEntry)
DESCRIPTOR._options = None
_HLOPROFILEPRINTERDATA_EXTRAMETRICSENTRY._options = None



import socket as _socket
import time as _time
import threading as _threading
import sys as _sys
import os as _os

from . import load_library
from . import std

kNUMANoAffinity = -1
kLittleEndian = _sys.byteorder == 'little'

def hostname() -> str:
  return _socket.gethostname()

def job_name() -> str:
  return _os.getenv("TF_JOB_NAME") or ""

def num_schedulable_cpus() -> int:
  count = std.thread.hardware_concurrency()
  if count > 0:
    return count
  kDefaultCores = 4  # Semi-conservative guess
  print("can't determine number of CPU cores: assuming %d" % kDefaultCores, file=_sys.stderr)
  return kDefaultCores

def max_parallelism(numa_node: int = kNUMANoAffinity) -> int:
  if numa_node != kNUMANoAffinity:
    # Assume that CPUs are equally distributed over available NUMA nodes.
    # This may not be true, but there isn't currently a better way of
    # determining the number of CPUs specific to the requested node.
    return num_schedulable_cpus() // numa_num_nodes()
  return num_schedulable_cpus()

def num_total_cpus() -> int:
  return _os.cpu_count()

def numa_enabled() -> bool:
  return numa_num_nodes() > 1

def numa_num_nodes() -> int:
  return 1  # NUMA not yet implemented

def usleep(micros: int):
  if _usleep is not None:
    _usleep(int(micros))
  else:
    _time.sleep(micros / 1000000.0)

def get_current_thread_id() -> int:
  return _threading.get_ident()


_status, libc = load_library.load_dynamic_library(load_library.format_library_file_name('c', ''))
if not _status.ok():
  _status, libc = load_library.load_dynamic_library(load_library.format_library_file_name('c', '6'))
_status, _usleep = load_library.get_symbol_from_library(libc, 'usleep')
del _status



# If tensorflow has already been imported, use their _pb2 moduels to avoid duplicate protobuf registry entries.
import sys
if 'tensorflow' in sys.modules:
  for k, v in list(sys.modules.items()):
    if k.startswith('tensorflow.') and k.endswith('_pb2'):
      sys.modules[__name__ + '.' + k] = v
  del k, v
del sys




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.protobuf import worker_pb2 as tensorflow_dot_core_dot_protobuf_dot_worker__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/worker_service.proto', package='tensorflow.grpc', syntax='proto3', serialized_options=b'\n\x1aorg.tensorflow.distruntimeB\x13WorkerServiceProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/protobuf/worker_service.proto\x12\x0ftensorflow.grpc\x1a%tensorflow/core/protobuf/worker.proto2\xf0\t\n\rWorkerService\x12H\n\tGetStatus\x12\x1c.tensorflow.GetStatusRequest\x1a\x1d.tensorflow.GetStatusResponse\x12f\n\x13CreateWorkerSession\x12&.tensorflow.CreateWorkerSessionRequest\x1a\'.tensorflow.CreateWorkerSessionResponse\x12f\n\x13DeleteWorkerSession\x12&.tensorflow.DeleteWorkerSessionRequest\x1a\'.tensorflow.DeleteWorkerSessionResponse\x12T\n\rRegisterGraph\x12 .tensorflow.RegisterGraphRequest\x1a!.tensorflow.RegisterGraphResponse\x12Z\n\x0fDeregisterGraph\x12".tensorflow.DeregisterGraphRequest\x1a#.tensorflow.DeregisterGraphResponse\x12E\n\x08RunGraph\x12\x1b.tensorflow.RunGraphRequest\x1a\x1c.tensorflow.RunGraphResponse\x12Q\n\x0cCleanupGraph\x12\x1f.tensorflow.CleanupGraphRequest\x1a .tensorflow.CleanupGraphResponse\x12K\n\nCleanupAll\x12\x1d.tensorflow.CleanupAllRequest\x1a\x1e.tensorflow.CleanupAllResponse\x12M\n\nRecvTensor\x12\x1d.tensorflow.RecvTensorRequest\x1a\x1e.tensorflow.RecvTensorResponse"\x00\x12B\n\x07Logging\x12\x1a.tensorflow.LoggingRequest\x1a\x1b.tensorflow.LoggingResponse\x12B\n\x07Tracing\x12\x1a.tensorflow.TracingRequest\x1a\x1b.tensorflow.TracingResponse\x12D\n\x07RecvBuf\x12\x1a.tensorflow.RecvBufRequest\x1a\x1b.tensorflow.RecvBufResponse"\x00\x12Z\n\x0fGetStepSequence\x12".tensorflow.GetStepSequenceRequest\x1a#.tensorflow.GetStepSequenceResponse\x12T\n\rCompleteGroup\x12 .tensorflow.CompleteGroupRequest\x1a!.tensorflow.CompleteGroupResponse\x12]\n\x10CompleteInstance\x12#.tensorflow.CompleteInstanceRequest\x1a$.tensorflow.CompleteInstanceResponseB\x8a\x01\n\x1aorg.tensorflow.distruntimeB\x13WorkerServiceProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_worker__pb2.DESCRIPTOR])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DESCRIPTOR._options = None
_WORKERSERVICE = _descriptor.ServiceDescriptor(name='WorkerService', full_name='tensorflow.grpc.WorkerService', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=106, serialized_end=1370, methods=[_descriptor.MethodDescriptor(name='GetStatus', full_name='tensorflow.grpc.WorkerService.GetStatus', index=0, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._GETSTATUSREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._GETSTATUSRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CreateWorkerSession', full_name='tensorflow.grpc.WorkerService.CreateWorkerSession', index=1, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CREATEWORKERSESSIONREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CREATEWORKERSESSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='DeleteWorkerSession', full_name='tensorflow.grpc.WorkerService.DeleteWorkerSession', index=2, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._DELETEWORKERSESSIONREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._DELETEWORKERSESSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RegisterGraph', full_name='tensorflow.grpc.WorkerService.RegisterGraph', index=3, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._REGISTERGRAPHREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._REGISTERGRAPHRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='DeregisterGraph', full_name='tensorflow.grpc.WorkerService.DeregisterGraph', index=4, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._DEREGISTERGRAPHREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._DEREGISTERGRAPHRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RunGraph', full_name='tensorflow.grpc.WorkerService.RunGraph', index=5, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RUNGRAPHREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RUNGRAPHRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CleanupGraph', full_name='tensorflow.grpc.WorkerService.CleanupGraph', index=6, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CLEANUPGRAPHREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CLEANUPGRAPHRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CleanupAll', full_name='tensorflow.grpc.WorkerService.CleanupAll', index=7, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CLEANUPALLREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._CLEANUPALLRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RecvTensor', full_name='tensorflow.grpc.WorkerService.RecvTensor', index=8, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RECVTENSORREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RECVTENSORRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Logging', full_name='tensorflow.grpc.WorkerService.Logging', index=9, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._LOGGINGREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._LOGGINGRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Tracing', full_name='tensorflow.grpc.WorkerService.Tracing', index=10, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._TRACINGREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._TRACINGRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RecvBuf', full_name='tensorflow.grpc.WorkerService.RecvBuf', index=11, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RECVBUFREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._RECVBUFRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetStepSequence', full_name='tensorflow.grpc.WorkerService.GetStepSequence', index=12, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._GETSTEPSEQUENCEREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._GETSTEPSEQUENCERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CompleteGroup', full_name='tensorflow.grpc.WorkerService.CompleteGroup', index=13, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._COMPLETEGROUPREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._COMPLETEGROUPRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CompleteInstance', full_name='tensorflow.grpc.WorkerService.CompleteInstance', index=14, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._COMPLETEINSTANCEREQUEST, output_type=tensorflow_dot_core_dot_protobuf_dot_worker__pb2._COMPLETEINSTANCERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_WORKERSERVICE)
DESCRIPTOR.services_by_name['WorkerService'] = _WORKERSERVICE




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/data/dataset.proto', package='tensorflow.data', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n"tensorflow/core/data/dataset.proto\x12\x0ftensorflow.data\x1a&tensorflow/core/framework/tensor.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"\x91\x01\n\x1bCompressedComponentMetadata\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x122\n\x0ctensor_shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12\x19\n\x11tensor_size_bytes\x18\x03 \x01(\x03"k\n\x11CompressedElement\x12\x0c\n\x04data\x18\x01 \x01(\x0c\x12H\n\x12component_metadata\x18\x02 \x03(\x0b2,.tensorflow.data.CompressedComponentMetadata"B\n\x13UncompressedElement\x12+\n\ncomponents\x18\x01 \x03(\x0b2\x17.tensorflow.TensorProtob\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_COMPRESSEDCOMPONENTMETADATA = _descriptor.Descriptor(name='CompressedComponentMetadata', full_name='tensorflow.data.CompressedComponentMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.data.CompressedComponentMetadata.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_shape', full_name='tensorflow.data.CompressedComponentMetadata.tensor_shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_size_bytes', full_name='tensorflow.data.CompressedComponentMetadata.tensor_size_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=181, serialized_end=326)
_COMPRESSEDELEMENT = _descriptor.Descriptor(name='CompressedElement', full_name='tensorflow.data.CompressedElement', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='data', full_name='tensorflow.data.CompressedElement.data', index=0, number=1, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='component_metadata', full_name='tensorflow.data.CompressedElement.component_metadata', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=328, serialized_end=435)
_UNCOMPRESSEDELEMENT = _descriptor.Descriptor(name='UncompressedElement', full_name='tensorflow.data.UncompressedElement', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='components', full_name='tensorflow.data.UncompressedElement.components', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=437, serialized_end=503)
_COMPRESSEDCOMPONENTMETADATA.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_COMPRESSEDCOMPONENTMETADATA.fields_by_name['tensor_shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_COMPRESSEDELEMENT.fields_by_name['component_metadata'].message_type = _COMPRESSEDCOMPONENTMETADATA
_UNCOMPRESSEDELEMENT.fields_by_name['components'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
DESCRIPTOR.message_types_by_name['CompressedComponentMetadata'] = _COMPRESSEDCOMPONENTMETADATA
DESCRIPTOR.message_types_by_name['CompressedElement'] = _COMPRESSEDELEMENT
DESCRIPTOR.message_types_by_name['UncompressedElement'] = _UNCOMPRESSEDELEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CompressedComponentMetadata = _reflection.GeneratedProtocolMessageType('CompressedComponentMetadata', (_message.Message,), {'DESCRIPTOR': _COMPRESSEDCOMPONENTMETADATA, '__module__': 'tensorflow.core.data.dataset_pb2'})
_sym_db.RegisterMessage(CompressedComponentMetadata)
CompressedElement = _reflection.GeneratedProtocolMessageType('CompressedElement', (_message.Message,), {'DESCRIPTOR': _COMPRESSEDELEMENT, '__module__': 'tensorflow.core.data.dataset_pb2'})
_sym_db.RegisterMessage(CompressedElement)
UncompressedElement = _reflection.GeneratedProtocolMessageType('UncompressedElement', (_message.Message,), {'DESCRIPTOR': _UNCOMPRESSEDELEMENT, '__module__': 'tensorflow.core.data.dataset_pb2'})
_sym_db.RegisterMessage(UncompressedElement)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.compiler.xla.service import hlo_pb2 as tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2
from .....tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
from .....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/tpu/kernels/tpu_executable_info.proto', package='tensorflow', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n5tensorflow/core/tpu/kernels/tpu_executable_info.proto\x12\ntensorflow\x1a)tensorflow/compiler/xla/service/hlo.proto\x1a&tensorflow/compiler/xla/xla_data.proto\x1a,tensorflow/core/framework/tensor_shape.proto"\x82\x04\n\x16TPUExecutableInfoProto\x12%\n\x0cinput_shapes\x18\x02 \x03(\x0b2\x0f.xla.ShapeProto\x12%\n\x0coutput_shape\x18\x03 \x01(\x0b2\x0f.xla.ShapeProto\x12M\n\x16dynamic_output_indices\x18\x0b \x03(\x0b2-.tensorflow.TPUExecutableInfoProto.ShapeIndex\x12L\n\x10variable_indices\x18\n \x03(\x0b22.tensorflow.TPUExecutableInfoProto.UpdateIndexPair\x12:\n\x14output_tensor_shapes\x18\x08 \x03(\x0b2\x1c.tensorflow.TensorShapeProto\x12(\n\x0esession_module\x18\x05 \x01(\x0b2\x10.xla.HloSnapshot\x125\n\x11device_assignment\x18\x06 \x01(\x0b2\x1a.xla.DeviceAssignmentProto\x1a1\n\x0fUpdateIndexPair\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0f\n\x07updated\x18\x02 \x01(\x08\x1a\x1b\n\nShapeIndex\x12\r\n\x05index\x18\x01 \x03(\x05J\x04\x08\x01\x10\x02J\x04\x08\x07\x10\x08J\x04\x08\x04\x10\x05"\xd7\x02\n\x14TPUHostTransferProto\x12\x0f\n\x07channel\x18\x01 \x01(\x03\x12E\n\tdirection\x18\x02 \x01(\x0e22.tensorflow.TPUHostTransferProto.TransferDirection\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x1a\n\x12nested_while_level\x18\x04 \x01(\x03\x12\x1e\n\x05shape\x18\x05 \x01(\x0b2\x0f.xla.ShapeProto\x12\x15\n\rbuffer_offset\x18\x06 \x01(\x03\x12)\n\roriginal_type\x18\x07 \x01(\x0e2\x12.xla.PrimitiveType\x12\x15\n\ris_lower_bits\x18\x08 \x01(\x08"E\n\x11TransferDirection\x12\x08\n\x04NONE\x10\x00\x12\x12\n\x0eDEVICE_TO_HOST\x10\x01\x12\x12\n\x0eHOST_TO_DEVICE\x10\x02"T\n\x18TPUHostTransferInfoProto\x128\n\x0ehost_transfers\x18\x01 \x03(\x0b2 .tensorflow.TPUHostTransferProtob\x06proto3', dependencies=[tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR])
_TPUHOSTTRANSFERPROTO_TRANSFERDIRECTION = _descriptor.EnumDescriptor(name='TransferDirection', full_name='tensorflow.TPUHostTransferProto.TransferDirection', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='NONE', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DEVICE_TO_HOST', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='HOST_TO_DEVICE', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=990, serialized_end=1059)
_sym_db.RegisterEnumDescriptor(_TPUHOSTTRANSFERPROTO_TRANSFERDIRECTION)
_TPUEXECUTABLEINFOPROTO_UPDATEINDEXPAIR = _descriptor.Descriptor(name='UpdateIndexPair', full_name='tensorflow.TPUExecutableInfoProto.UpdateIndexPair', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='index', full_name='tensorflow.TPUExecutableInfoProto.UpdateIndexPair.index', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='updated', full_name='tensorflow.TPUExecutableInfoProto.UpdateIndexPair.updated', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=617, serialized_end=666)
_TPUEXECUTABLEINFOPROTO_SHAPEINDEX = _descriptor.Descriptor(name='ShapeIndex', full_name='tensorflow.TPUExecutableInfoProto.ShapeIndex', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='index', full_name='tensorflow.TPUExecutableInfoProto.ShapeIndex.index', index=0, number=1, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=668, serialized_end=695)
_TPUEXECUTABLEINFOPROTO = _descriptor.Descriptor(name='TPUExecutableInfoProto', full_name='tensorflow.TPUExecutableInfoProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='input_shapes', full_name='tensorflow.TPUExecutableInfoProto.input_shapes', index=0, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_shape', full_name='tensorflow.TPUExecutableInfoProto.output_shape', index=1, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dynamic_output_indices', full_name='tensorflow.TPUExecutableInfoProto.dynamic_output_indices', index=2, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='variable_indices', full_name='tensorflow.TPUExecutableInfoProto.variable_indices', index=3, number=10, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_tensor_shapes', full_name='tensorflow.TPUExecutableInfoProto.output_tensor_shapes', index=4, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='session_module', full_name='tensorflow.TPUExecutableInfoProto.session_module', index=5, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_assignment', full_name='tensorflow.TPUExecutableInfoProto.device_assignment', index=6, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TPUEXECUTABLEINFOPROTO_UPDATEINDEXPAIR, _TPUEXECUTABLEINFOPROTO_SHAPEINDEX], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=199, serialized_end=713)
_TPUHOSTTRANSFERPROTO = _descriptor.Descriptor(name='TPUHostTransferProto', full_name='tensorflow.TPUHostTransferProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='channel', full_name='tensorflow.TPUHostTransferProto.channel', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='direction', full_name='tensorflow.TPUHostTransferProto.direction', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='key', full_name='tensorflow.TPUHostTransferProto.key', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='nested_while_level', full_name='tensorflow.TPUHostTransferProto.nested_while_level', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.TPUHostTransferProto.shape', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='buffer_offset', full_name='tensorflow.TPUHostTransferProto.buffer_offset', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='original_type', full_name='tensorflow.TPUHostTransferProto.original_type', index=6, number=7, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_lower_bits', full_name='tensorflow.TPUHostTransferProto.is_lower_bits', index=7, number=8, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_TPUHOSTTRANSFERPROTO_TRANSFERDIRECTION], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=716, serialized_end=1059)
_TPUHOSTTRANSFERINFOPROTO = _descriptor.Descriptor(name='TPUHostTransferInfoProto', full_name='tensorflow.TPUHostTransferInfoProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_transfers', full_name='tensorflow.TPUHostTransferInfoProto.host_transfers', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1061, serialized_end=1145)
_TPUEXECUTABLEINFOPROTO_UPDATEINDEXPAIR.containing_type = _TPUEXECUTABLEINFOPROTO
_TPUEXECUTABLEINFOPROTO_SHAPEINDEX.containing_type = _TPUEXECUTABLEINFOPROTO
_TPUEXECUTABLEINFOPROTO.fields_by_name['input_shapes'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SHAPEPROTO
_TPUEXECUTABLEINFOPROTO.fields_by_name['output_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SHAPEPROTO
_TPUEXECUTABLEINFOPROTO.fields_by_name['dynamic_output_indices'].message_type = _TPUEXECUTABLEINFOPROTO_SHAPEINDEX
_TPUEXECUTABLEINFOPROTO.fields_by_name['variable_indices'].message_type = _TPUEXECUTABLEINFOPROTO_UPDATEINDEXPAIR
_TPUEXECUTABLEINFOPROTO.fields_by_name['output_tensor_shapes'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_TPUEXECUTABLEINFOPROTO.fields_by_name['session_module'].message_type = tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2._HLOSNAPSHOT
_TPUEXECUTABLEINFOPROTO.fields_by_name['device_assignment'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._DEVICEASSIGNMENTPROTO
_TPUHOSTTRANSFERPROTO.fields_by_name['direction'].enum_type = _TPUHOSTTRANSFERPROTO_TRANSFERDIRECTION
_TPUHOSTTRANSFERPROTO.fields_by_name['shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SHAPEPROTO
_TPUHOSTTRANSFERPROTO.fields_by_name['original_type'].enum_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PRIMITIVETYPE
_TPUHOSTTRANSFERPROTO_TRANSFERDIRECTION.containing_type = _TPUHOSTTRANSFERPROTO
_TPUHOSTTRANSFERINFOPROTO.fields_by_name['host_transfers'].message_type = _TPUHOSTTRANSFERPROTO
DESCRIPTOR.message_types_by_name['TPUExecutableInfoProto'] = _TPUEXECUTABLEINFOPROTO
DESCRIPTOR.message_types_by_name['TPUHostTransferProto'] = _TPUHOSTTRANSFERPROTO
DESCRIPTOR.message_types_by_name['TPUHostTransferInfoProto'] = _TPUHOSTTRANSFERINFOPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TPUExecutableInfoProto = _reflection.GeneratedProtocolMessageType('TPUExecutableInfoProto', (_message.Message,), {'UpdateIndexPair': _reflection.GeneratedProtocolMessageType('UpdateIndexPair', (_message.Message,), {'DESCRIPTOR': _TPUEXECUTABLEINFOPROTO_UPDATEINDEXPAIR, '__module__': 'tensorflow.core.tpu.kernels.tpu_executable_info_pb2'}), 'ShapeIndex': _reflection.GeneratedProtocolMessageType('ShapeIndex', (_message.Message,), {'DESCRIPTOR': _TPUEXECUTABLEINFOPROTO_SHAPEINDEX, '__module__': 'tensorflow.core.tpu.kernels.tpu_executable_info_pb2'}), 'DESCRIPTOR': _TPUEXECUTABLEINFOPROTO, '__module__': 'tensorflow.core.tpu.kernels.tpu_executable_info_pb2'})
_sym_db.RegisterMessage(TPUExecutableInfoProto)
_sym_db.RegisterMessage(TPUExecutableInfoProto.UpdateIndexPair)
_sym_db.RegisterMessage(TPUExecutableInfoProto.ShapeIndex)
TPUHostTransferProto = _reflection.GeneratedProtocolMessageType('TPUHostTransferProto', (_message.Message,), {'DESCRIPTOR': _TPUHOSTTRANSFERPROTO, '__module__': 'tensorflow.core.tpu.kernels.tpu_executable_info_pb2'})
_sym_db.RegisterMessage(TPUHostTransferProto)
TPUHostTransferInfoProto = _reflection.GeneratedProtocolMessageType('TPUHostTransferInfoProto', (_message.Message,), {'DESCRIPTOR': _TPUHOSTTRANSFERINFOPROTO, '__module__': 'tensorflow.core.tpu.kernels.tpu_executable_info_pb2'})
_sym_db.RegisterMessage(TPUHostTransferInfoProto)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import attr_value_pb2 as tensorflow_dot_core_dot_framework_dot_attr__value__pb2
from ....tensorflow.core.framework import device_attributes_pb2 as tensorflow_dot_core_dot_framework_dot_device__attributes__pb2
from ....tensorflow.core.framework import function_pb2 as tensorflow_dot_core_dot_framework_dot_function__pb2
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import versions_pb2 as tensorflow_dot_core_dot_framework_dot_versions__pb2
from ....tensorflow.core.protobuf import remote_tensor_handle_pb2 as tensorflow_dot_core_dot_protobuf_dot_remote__tensor__handle__pb2
from ....tensorflow.core.protobuf import tensorflow_server_pb2 as tensorflow_dot_core_dot_protobuf_dot_tensorflow__server__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/eager_service.proto', package='tensorflow.eager', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n,tensorflow/core/protobuf/eager_service.proto\x12\x10tensorflow.eager\x1a*tensorflow/core/framework/attr_value.proto\x1a1tensorflow/core/framework/device_attributes.proto\x1a(tensorflow/core/framework/function.proto\x1a&tensorflow/core/framework/tensor.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a(tensorflow/core/framework/versions.proto\x1a3tensorflow/core/protobuf/remote_tensor_handle.proto\x1a0tensorflow/core/protobuf/tensorflow_server.proto"\xca\x03\n\tOperation\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x124\n\top_inputs\x18\n \x03(\x0b2!.tensorflow.eager.Operation.Input\x12\x16\n\x0econtrol_op_ids\x18\x04 \x03(\x03\x125\n\x05attrs\x18\x05 \x03(\x0b2&.tensorflow.eager.Operation.AttrsEntry\x12\x0e\n\x06device\x18\x06 \x01(\t\x12\x1d\n\x15is_component_function\x18\x07 \x01(\x08\x12\x14\n\x0cfunc_step_id\x18\x08 \x01(\x03\x12\x13\n\x0bis_function\x18\t \x01(\x08\x1ay\n\x05Input\x12=\n\rremote_handle\x18\x01 \x01(\x0b2$.tensorflow.eager.RemoteTensorHandleH\x00\x12)\n\x06tensor\x18\x02 \x01(\x0b2\x17.tensorflow.TensorProtoH\x00B\x06\n\x04item\x1aC\n\nAttrsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b2\x15.tensorflow.AttrValue:\x028\x01J\x04\x08\x03\x10\x04"\xe0\x03\n\tQueueItem\x12@\n\x10handle_to_decref\x18\x01 \x01(\x0b2$.tensorflow.eager.RemoteTensorHandleH\x00\x120\n\toperation\x18\x02 \x01(\x0b2\x1b.tensorflow.eager.OperationH\x00\x125\n\x0bsend_tensor\x18\x03 \x01(\x0b2\x1e.tensorflow.eager.SendTensorOpH\x00\x12A\n\x11register_function\x18\x04 \x01(\x0b2$.tensorflow.eager.RegisterFunctionOpH\x00\x12?\n\x10cleanup_function\x18\x05 \x01(\x0b2#.tensorflow.eager.CleanupFunctionOpH\x00\x12X\n\x1fsync_remote_executor_for_stream\x18\x06 \x01(\x0b2-.tensorflow.eager.SyncRemoteExecutorForStreamH\x00\x12B\n\x12send_packed_handle\x18\x07 \x01(\x0b2$.tensorflow.eager.SendPackedHandleOpH\x00B\x06\n\x04item"u\n\rQueueResponse\x12+\n\x05shape\x18\x01 \x03(\x0b2\x1c.tensorflow.TensorShapeProto\x12\x0e\n\x06device\x18\x03 \x03(\t\x12\'\n\x06tensor\x18\x02 \x03(\x0b2\x17.tensorflow.TensorProto"\xb4\x02\n\x14CreateContextRequest\x12)\n\nserver_def\x18\x01 \x01(\x0b2\x15.tensorflow.ServerDef\x12\r\n\x05async\x18\x02 \x01(\x08\x12\x17\n\x0fkeep_alive_secs\x18\x03 \x01(\x03\x12+\n\x0bversion_def\x18\x04 \x01(\x0b2\x16.tensorflow.VersionDef\x12?\n\x19cluster_device_attributes\x18\x06 \x03(\x0b2\x1c.tensorflow.DeviceAttributes\x12\x12\n\ncontext_id\x18\x07 \x01(\x06\x12\x17\n\x0fcontext_view_id\x18\x08 \x01(\x06\x12(\n lazy_copy_remote_function_inputs\x18\t \x01(\x08J\x04\x08\x05\x10\x06"V\n\x15CreateContextResponse\x127\n\x11device_attributes\x18\x02 \x03(\x0b2\x1c.tensorflow.DeviceAttributesJ\x04\x08\x01\x10\x02"\xaf\x01\n\x14UpdateContextRequest\x12)\n\nserver_def\x18\x01 \x01(\x0b2\x15.tensorflow.ServerDef\x12?\n\x19cluster_device_attributes\x18\x02 \x03(\x0b2\x1c.tensorflow.DeviceAttributes\x12\x12\n\ncontext_id\x18\x03 \x01(\x06\x12\x17\n\x0fcontext_view_id\x18\x04 \x01(\x06"P\n\x15UpdateContextResponse\x127\n\x11device_attributes\x18\x01 \x03(\x0b2\x1c.tensorflow.DeviceAttributes"P\n\x0eEnqueueRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\x06\x12*\n\x05queue\x18\x03 \x03(\x0b2\x1b.tensorflow.eager.QueueItem"J\n\x0fEnqueueResponse\x127\n\x0equeue_response\x18\x01 \x03(\x0b2\x1f.tensorflow.eager.QueueResponse"9\n\x14WaitQueueDoneRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\x06\x12\r\n\x05op_id\x18\x02 \x03(\x03"\x17\n\x15WaitQueueDoneResponse"u\n\x1bRunComponentFunctionRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\x06\x12.\n\toperation\x18\x02 \x01(\x0b2\x1b.tensorflow.eager.Operation\x12\x12\n\noutput_num\x18\x03 \x03(\x05"t\n\x1cRunComponentFunctionResponse\x12+\n\x05shape\x18\x01 \x03(\x0b2\x1c.tensorflow.TensorShapeProto\x12\'\n\x06tensor\x18\x02 \x03(\x0b2\x17.tensorflow.TensorProto"&\n\x10KeepAliveRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\x06",\n\x11KeepAliveResponse\x12\x17\n\x0fcontext_view_id\x18\x01 \x01(\x06"B\n\x13CloseContextRequest\x12\x12\n\ncontext_id\x18\x01 \x01(\x06\x12\x17\n\x0fcontext_view_id\x18\x02 \x01(\x06"\x16\n\x14CloseContextResponse"\x93\x01\n\x12RegisterFunctionOp\x12-\n\x0cfunction_def\x18\x01 \x01(\x0b2\x17.tensorflow.FunctionDef\x12\x1d\n\x15is_component_function\x18\x02 \x01(\x08\x12/\n\x07library\x18\x03 \x01(\x0b2\x1e.tensorflow.FunctionDefLibrary"$\n\x11CleanupFunctionOp\x12\x0f\n\x07step_id\x18\x01 \x01(\x03"\x1d\n\x1bSyncRemoteExecutorForStream"\\\n\x0cSendTensorOp\x12\r\n\x05op_id\x18\x01 \x01(\x03\x12(\n\x07tensors\x18\x02 \x03(\x0b2\x17.tensorflow.TensorProto\x12\x13\n\x0bdevice_name\x18\x03 \x01(\t"\xe6\x02\n\x12SendPackedHandleOp\x12\r\n\x05op_id\x18\x01 \x01(\x03\x12<\n\x07handles\x18\x02 \x03(\x0b2+.tensorflow.eager.SendPackedHandleOp.Handle\x12\x13\n\x0bdevice_name\x18\x03 \x01(\t\x1aL\n\x11LocalTensorHandle\x12\'\n\x06tensor\x18\x01 \x01(\x0b2\x17.tensorflow.TensorProto\x12\x0e\n\x06device\x18\x02 \x01(\t\x1a\x9f\x01\n\x06Handle\x12N\n\x0clocal_handle\x18\x01 \x01(\x0b26.tensorflow.eager.SendPackedHandleOp.LocalTensorHandleH\x00\x12=\n\rremote_handle\x18\x02 \x01(\x0b2$.tensorflow.eager.RemoteTensorHandleH\x00B\x06\n\x04item2\x8d\x06\n\x0cEagerService\x12`\n\rCreateContext\x12&.tensorflow.eager.CreateContextRequest\x1a\'.tensorflow.eager.CreateContextResponse\x12`\n\rUpdateContext\x12&.tensorflow.eager.UpdateContextRequest\x1a\'.tensorflow.eager.UpdateContextResponse\x12N\n\x07Enqueue\x12 .tensorflow.eager.EnqueueRequest\x1a!.tensorflow.eager.EnqueueResponse\x12[\n\x10StreamingEnqueue\x12 .tensorflow.eager.EnqueueRequest\x1a!.tensorflow.eager.EnqueueResponse(\x010\x01\x12`\n\rWaitQueueDone\x12&.tensorflow.eager.WaitQueueDoneRequest\x1a\'.tensorflow.eager.WaitQueueDoneResponse\x12u\n\x14RunComponentFunction\x12-.tensorflow.eager.RunComponentFunctionRequest\x1a..tensorflow.eager.RunComponentFunctionResponse\x12T\n\tKeepAlive\x12".tensorflow.eager.KeepAliveRequest\x1a#.tensorflow.eager.KeepAliveResponse\x12]\n\x0cCloseContext\x12%.tensorflow.eager.CloseContextRequest\x1a&.tensorflow.eager.CloseContextResponseBWZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_attr__value__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_device__attributes__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_function__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_versions__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_remote__tensor__handle__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_tensorflow__server__pb2.DESCRIPTOR])
_OPERATION_INPUT = _descriptor.Descriptor(name='Input', full_name='tensorflow.eager.Operation.Input', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='remote_handle', full_name='tensorflow.eager.Operation.Input.remote_handle', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.eager.Operation.Input.tensor', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='item', full_name='tensorflow.eager.Operation.Input.item', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=697, serialized_end=818)
_OPERATION_ATTRSENTRY = _descriptor.Descriptor(name='AttrsEntry', full_name='tensorflow.eager.Operation.AttrsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.eager.Operation.AttrsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.eager.Operation.AttrsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=820, serialized_end=887)
_OPERATION = _descriptor.Descriptor(name='Operation', full_name='tensorflow.eager.Operation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.eager.Operation.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.eager.Operation.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_inputs', full_name='tensorflow.eager.Operation.op_inputs', index=2, number=10, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='control_op_ids', full_name='tensorflow.eager.Operation.control_op_ids', index=3, number=4, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='attrs', full_name='tensorflow.eager.Operation.attrs', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device', full_name='tensorflow.eager.Operation.device', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_component_function', full_name='tensorflow.eager.Operation.is_component_function', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='func_step_id', full_name='tensorflow.eager.Operation.func_step_id', index=7, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_function', full_name='tensorflow.eager.Operation.is_function', index=8, number=9, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_OPERATION_INPUT, _OPERATION_ATTRSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=435, serialized_end=893)
_QUEUEITEM = _descriptor.Descriptor(name='QueueItem', full_name='tensorflow.eager.QueueItem', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='handle_to_decref', full_name='tensorflow.eager.QueueItem.handle_to_decref', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operation', full_name='tensorflow.eager.QueueItem.operation', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='send_tensor', full_name='tensorflow.eager.QueueItem.send_tensor', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='register_function', full_name='tensorflow.eager.QueueItem.register_function', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cleanup_function', full_name='tensorflow.eager.QueueItem.cleanup_function', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sync_remote_executor_for_stream', full_name='tensorflow.eager.QueueItem.sync_remote_executor_for_stream', index=5, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='send_packed_handle', full_name='tensorflow.eager.QueueItem.send_packed_handle', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='item', full_name='tensorflow.eager.QueueItem.item', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=896, serialized_end=1376)
_QUEUERESPONSE = _descriptor.Descriptor(name='QueueResponse', full_name='tensorflow.eager.QueueResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='shape', full_name='tensorflow.eager.QueueResponse.shape', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device', full_name='tensorflow.eager.QueueResponse.device', index=1, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.eager.QueueResponse.tensor', index=2, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1378, serialized_end=1495)
_CREATECONTEXTREQUEST = _descriptor.Descriptor(name='CreateContextRequest', full_name='tensorflow.eager.CreateContextRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='server_def', full_name='tensorflow.eager.CreateContextRequest.server_def', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='async', full_name='tensorflow.eager.CreateContextRequest.async', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='keep_alive_secs', full_name='tensorflow.eager.CreateContextRequest.keep_alive_secs', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='version_def', full_name='tensorflow.eager.CreateContextRequest.version_def', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cluster_device_attributes', full_name='tensorflow.eager.CreateContextRequest.cluster_device_attributes', index=4, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='context_id', full_name='tensorflow.eager.CreateContextRequest.context_id', index=5, number=7, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='context_view_id', full_name='tensorflow.eager.CreateContextRequest.context_view_id', index=6, number=8, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='lazy_copy_remote_function_inputs', full_name='tensorflow.eager.CreateContextRequest.lazy_copy_remote_function_inputs', index=7, number=9, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1498, serialized_end=1806)
_CREATECONTEXTRESPONSE = _descriptor.Descriptor(name='CreateContextResponse', full_name='tensorflow.eager.CreateContextResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device_attributes', full_name='tensorflow.eager.CreateContextResponse.device_attributes', index=0, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1808, serialized_end=1894)
_UPDATECONTEXTREQUEST = _descriptor.Descriptor(name='UpdateContextRequest', full_name='tensorflow.eager.UpdateContextRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='server_def', full_name='tensorflow.eager.UpdateContextRequest.server_def', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cluster_device_attributes', full_name='tensorflow.eager.UpdateContextRequest.cluster_device_attributes', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='context_id', full_name='tensorflow.eager.UpdateContextRequest.context_id', index=2, number=3, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='context_view_id', full_name='tensorflow.eager.UpdateContextRequest.context_view_id', index=3, number=4, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1897, serialized_end=2072)
_UPDATECONTEXTRESPONSE = _descriptor.Descriptor(name='UpdateContextResponse', full_name='tensorflow.eager.UpdateContextResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device_attributes', full_name='tensorflow.eager.UpdateContextResponse.device_attributes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2074, serialized_end=2154)
_ENQUEUEREQUEST = _descriptor.Descriptor(name='EnqueueRequest', full_name='tensorflow.eager.EnqueueRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='context_id', full_name='tensorflow.eager.EnqueueRequest.context_id', index=0, number=1, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='queue', full_name='tensorflow.eager.EnqueueRequest.queue', index=1, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2156, serialized_end=2236)
_ENQUEUERESPONSE = _descriptor.Descriptor(name='EnqueueResponse', full_name='tensorflow.eager.EnqueueResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='queue_response', full_name='tensorflow.eager.EnqueueResponse.queue_response', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2238, serialized_end=2312)
_WAITQUEUEDONEREQUEST = _descriptor.Descriptor(name='WaitQueueDoneRequest', full_name='tensorflow.eager.WaitQueueDoneRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='context_id', full_name='tensorflow.eager.WaitQueueDoneRequest.context_id', index=0, number=1, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_id', full_name='tensorflow.eager.WaitQueueDoneRequest.op_id', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2314, serialized_end=2371)
_WAITQUEUEDONERESPONSE = _descriptor.Descriptor(name='WaitQueueDoneResponse', full_name='tensorflow.eager.WaitQueueDoneResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2373, serialized_end=2396)
_RUNCOMPONENTFUNCTIONREQUEST = _descriptor.Descriptor(name='RunComponentFunctionRequest', full_name='tensorflow.eager.RunComponentFunctionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='context_id', full_name='tensorflow.eager.RunComponentFunctionRequest.context_id', index=0, number=1, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operation', full_name='tensorflow.eager.RunComponentFunctionRequest.operation', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_num', full_name='tensorflow.eager.RunComponentFunctionRequest.output_num', index=2, number=3, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2398, serialized_end=2515)
_RUNCOMPONENTFUNCTIONRESPONSE = _descriptor.Descriptor(name='RunComponentFunctionResponse', full_name='tensorflow.eager.RunComponentFunctionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='shape', full_name='tensorflow.eager.RunComponentFunctionResponse.shape', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.eager.RunComponentFunctionResponse.tensor', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2517, serialized_end=2633)
_KEEPALIVEREQUEST = _descriptor.Descriptor(name='KeepAliveRequest', full_name='tensorflow.eager.KeepAliveRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='context_id', full_name='tensorflow.eager.KeepAliveRequest.context_id', index=0, number=1, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2635, serialized_end=2673)
_KEEPALIVERESPONSE = _descriptor.Descriptor(name='KeepAliveResponse', full_name='tensorflow.eager.KeepAliveResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='context_view_id', full_name='tensorflow.eager.KeepAliveResponse.context_view_id', index=0, number=1, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2675, serialized_end=2719)
_CLOSECONTEXTREQUEST = _descriptor.Descriptor(name='CloseContextRequest', full_name='tensorflow.eager.CloseContextRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='context_id', full_name='tensorflow.eager.CloseContextRequest.context_id', index=0, number=1, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='context_view_id', full_name='tensorflow.eager.CloseContextRequest.context_view_id', index=1, number=2, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2721, serialized_end=2787)
_CLOSECONTEXTRESPONSE = _descriptor.Descriptor(name='CloseContextResponse', full_name='tensorflow.eager.CloseContextResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2789, serialized_end=2811)
_REGISTERFUNCTIONOP = _descriptor.Descriptor(name='RegisterFunctionOp', full_name='tensorflow.eager.RegisterFunctionOp', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='function_def', full_name='tensorflow.eager.RegisterFunctionOp.function_def', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_component_function', full_name='tensorflow.eager.RegisterFunctionOp.is_component_function', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='library', full_name='tensorflow.eager.RegisterFunctionOp.library', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2814, serialized_end=2961)
_CLEANUPFUNCTIONOP = _descriptor.Descriptor(name='CleanupFunctionOp', full_name='tensorflow.eager.CleanupFunctionOp', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.eager.CleanupFunctionOp.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2963, serialized_end=2999)
_SYNCREMOTEEXECUTORFORSTREAM = _descriptor.Descriptor(name='SyncRemoteExecutorForStream', full_name='tensorflow.eager.SyncRemoteExecutorForStream', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3001, serialized_end=3030)
_SENDTENSOROP = _descriptor.Descriptor(name='SendTensorOp', full_name='tensorflow.eager.SendTensorOp', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op_id', full_name='tensorflow.eager.SendTensorOp.op_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensors', full_name='tensorflow.eager.SendTensorOp.tensors', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_name', full_name='tensorflow.eager.SendTensorOp.device_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3032, serialized_end=3124)
_SENDPACKEDHANDLEOP_LOCALTENSORHANDLE = _descriptor.Descriptor(name='LocalTensorHandle', full_name='tensorflow.eager.SendPackedHandleOp.LocalTensorHandle', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.eager.SendPackedHandleOp.LocalTensorHandle.tensor', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device', full_name='tensorflow.eager.SendPackedHandleOp.LocalTensorHandle.device', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3247, serialized_end=3323)
_SENDPACKEDHANDLEOP_HANDLE = _descriptor.Descriptor(name='Handle', full_name='tensorflow.eager.SendPackedHandleOp.Handle', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='local_handle', full_name='tensorflow.eager.SendPackedHandleOp.Handle.local_handle', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='remote_handle', full_name='tensorflow.eager.SendPackedHandleOp.Handle.remote_handle', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='item', full_name='tensorflow.eager.SendPackedHandleOp.Handle.item', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=3326, serialized_end=3485)
_SENDPACKEDHANDLEOP = _descriptor.Descriptor(name='SendPackedHandleOp', full_name='tensorflow.eager.SendPackedHandleOp', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op_id', full_name='tensorflow.eager.SendPackedHandleOp.op_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='handles', full_name='tensorflow.eager.SendPackedHandleOp.handles', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_name', full_name='tensorflow.eager.SendPackedHandleOp.device_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_SENDPACKEDHANDLEOP_LOCALTENSORHANDLE, _SENDPACKEDHANDLEOP_HANDLE], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3127, serialized_end=3485)
_OPERATION_INPUT.fields_by_name['remote_handle'].message_type = tensorflow_dot_core_dot_protobuf_dot_remote__tensor__handle__pb2._REMOTETENSORHANDLE
_OPERATION_INPUT.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_OPERATION_INPUT.containing_type = _OPERATION
_OPERATION_INPUT.oneofs_by_name['item'].fields.append(_OPERATION_INPUT.fields_by_name['remote_handle'])
_OPERATION_INPUT.fields_by_name['remote_handle'].containing_oneof = _OPERATION_INPUT.oneofs_by_name['item']
_OPERATION_INPUT.oneofs_by_name['item'].fields.append(_OPERATION_INPUT.fields_by_name['tensor'])
_OPERATION_INPUT.fields_by_name['tensor'].containing_oneof = _OPERATION_INPUT.oneofs_by_name['item']
_OPERATION_ATTRSENTRY.fields_by_name['value'].message_type = tensorflow_dot_core_dot_framework_dot_attr__value__pb2._ATTRVALUE
_OPERATION_ATTRSENTRY.containing_type = _OPERATION
_OPERATION.fields_by_name['op_inputs'].message_type = _OPERATION_INPUT
_OPERATION.fields_by_name['attrs'].message_type = _OPERATION_ATTRSENTRY
_QUEUEITEM.fields_by_name['handle_to_decref'].message_type = tensorflow_dot_core_dot_protobuf_dot_remote__tensor__handle__pb2._REMOTETENSORHANDLE
_QUEUEITEM.fields_by_name['operation'].message_type = _OPERATION
_QUEUEITEM.fields_by_name['send_tensor'].message_type = _SENDTENSOROP
_QUEUEITEM.fields_by_name['register_function'].message_type = _REGISTERFUNCTIONOP
_QUEUEITEM.fields_by_name['cleanup_function'].message_type = _CLEANUPFUNCTIONOP
_QUEUEITEM.fields_by_name['sync_remote_executor_for_stream'].message_type = _SYNCREMOTEEXECUTORFORSTREAM
_QUEUEITEM.fields_by_name['send_packed_handle'].message_type = _SENDPACKEDHANDLEOP
_QUEUEITEM.oneofs_by_name['item'].fields.append(_QUEUEITEM.fields_by_name['handle_to_decref'])
_QUEUEITEM.fields_by_name['handle_to_decref'].containing_oneof = _QUEUEITEM.oneofs_by_name['item']
_QUEUEITEM.oneofs_by_name['item'].fields.append(_QUEUEITEM.fields_by_name['operation'])
_QUEUEITEM.fields_by_name['operation'].containing_oneof = _QUEUEITEM.oneofs_by_name['item']
_QUEUEITEM.oneofs_by_name['item'].fields.append(_QUEUEITEM.fields_by_name['send_tensor'])
_QUEUEITEM.fields_by_name['send_tensor'].containing_oneof = _QUEUEITEM.oneofs_by_name['item']
_QUEUEITEM.oneofs_by_name['item'].fields.append(_QUEUEITEM.fields_by_name['register_function'])
_QUEUEITEM.fields_by_name['register_function'].containing_oneof = _QUEUEITEM.oneofs_by_name['item']
_QUEUEITEM.oneofs_by_name['item'].fields.append(_QUEUEITEM.fields_by_name['cleanup_function'])
_QUEUEITEM.fields_by_name['cleanup_function'].containing_oneof = _QUEUEITEM.oneofs_by_name['item']
_QUEUEITEM.oneofs_by_name['item'].fields.append(_QUEUEITEM.fields_by_name['sync_remote_executor_for_stream'])
_QUEUEITEM.fields_by_name['sync_remote_executor_for_stream'].containing_oneof = _QUEUEITEM.oneofs_by_name['item']
_QUEUEITEM.oneofs_by_name['item'].fields.append(_QUEUEITEM.fields_by_name['send_packed_handle'])
_QUEUEITEM.fields_by_name['send_packed_handle'].containing_oneof = _QUEUEITEM.oneofs_by_name['item']
_QUEUERESPONSE.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_QUEUERESPONSE.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_CREATECONTEXTREQUEST.fields_by_name['server_def'].message_type = tensorflow_dot_core_dot_protobuf_dot_tensorflow__server__pb2._SERVERDEF
_CREATECONTEXTREQUEST.fields_by_name['version_def'].message_type = tensorflow_dot_core_dot_framework_dot_versions__pb2._VERSIONDEF
_CREATECONTEXTREQUEST.fields_by_name['cluster_device_attributes'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_CREATECONTEXTRESPONSE.fields_by_name['device_attributes'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_UPDATECONTEXTREQUEST.fields_by_name['server_def'].message_type = tensorflow_dot_core_dot_protobuf_dot_tensorflow__server__pb2._SERVERDEF
_UPDATECONTEXTREQUEST.fields_by_name['cluster_device_attributes'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_UPDATECONTEXTRESPONSE.fields_by_name['device_attributes'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_ENQUEUEREQUEST.fields_by_name['queue'].message_type = _QUEUEITEM
_ENQUEUERESPONSE.fields_by_name['queue_response'].message_type = _QUEUERESPONSE
_RUNCOMPONENTFUNCTIONREQUEST.fields_by_name['operation'].message_type = _OPERATION
_RUNCOMPONENTFUNCTIONRESPONSE.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_RUNCOMPONENTFUNCTIONRESPONSE.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_REGISTERFUNCTIONOP.fields_by_name['function_def'].message_type = tensorflow_dot_core_dot_framework_dot_function__pb2._FUNCTIONDEF
_REGISTERFUNCTIONOP.fields_by_name['library'].message_type = tensorflow_dot_core_dot_framework_dot_function__pb2._FUNCTIONDEFLIBRARY
_SENDTENSOROP.fields_by_name['tensors'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_SENDPACKEDHANDLEOP_LOCALTENSORHANDLE.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_SENDPACKEDHANDLEOP_LOCALTENSORHANDLE.containing_type = _SENDPACKEDHANDLEOP
_SENDPACKEDHANDLEOP_HANDLE.fields_by_name['local_handle'].message_type = _SENDPACKEDHANDLEOP_LOCALTENSORHANDLE
_SENDPACKEDHANDLEOP_HANDLE.fields_by_name['remote_handle'].message_type = tensorflow_dot_core_dot_protobuf_dot_remote__tensor__handle__pb2._REMOTETENSORHANDLE
_SENDPACKEDHANDLEOP_HANDLE.containing_type = _SENDPACKEDHANDLEOP
_SENDPACKEDHANDLEOP_HANDLE.oneofs_by_name['item'].fields.append(_SENDPACKEDHANDLEOP_HANDLE.fields_by_name['local_handle'])
_SENDPACKEDHANDLEOP_HANDLE.fields_by_name['local_handle'].containing_oneof = _SENDPACKEDHANDLEOP_HANDLE.oneofs_by_name['item']
_SENDPACKEDHANDLEOP_HANDLE.oneofs_by_name['item'].fields.append(_SENDPACKEDHANDLEOP_HANDLE.fields_by_name['remote_handle'])
_SENDPACKEDHANDLEOP_HANDLE.fields_by_name['remote_handle'].containing_oneof = _SENDPACKEDHANDLEOP_HANDLE.oneofs_by_name['item']
_SENDPACKEDHANDLEOP.fields_by_name['handles'].message_type = _SENDPACKEDHANDLEOP_HANDLE
DESCRIPTOR.message_types_by_name['Operation'] = _OPERATION
DESCRIPTOR.message_types_by_name['QueueItem'] = _QUEUEITEM
DESCRIPTOR.message_types_by_name['QueueResponse'] = _QUEUERESPONSE
DESCRIPTOR.message_types_by_name['CreateContextRequest'] = _CREATECONTEXTREQUEST
DESCRIPTOR.message_types_by_name['CreateContextResponse'] = _CREATECONTEXTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateContextRequest'] = _UPDATECONTEXTREQUEST
DESCRIPTOR.message_types_by_name['UpdateContextResponse'] = _UPDATECONTEXTRESPONSE
DESCRIPTOR.message_types_by_name['EnqueueRequest'] = _ENQUEUEREQUEST
DESCRIPTOR.message_types_by_name['EnqueueResponse'] = _ENQUEUERESPONSE
DESCRIPTOR.message_types_by_name['WaitQueueDoneRequest'] = _WAITQUEUEDONEREQUEST
DESCRIPTOR.message_types_by_name['WaitQueueDoneResponse'] = _WAITQUEUEDONERESPONSE
DESCRIPTOR.message_types_by_name['RunComponentFunctionRequest'] = _RUNCOMPONENTFUNCTIONREQUEST
DESCRIPTOR.message_types_by_name['RunComponentFunctionResponse'] = _RUNCOMPONENTFUNCTIONRESPONSE
DESCRIPTOR.message_types_by_name['KeepAliveRequest'] = _KEEPALIVEREQUEST
DESCRIPTOR.message_types_by_name['KeepAliveResponse'] = _KEEPALIVERESPONSE
DESCRIPTOR.message_types_by_name['CloseContextRequest'] = _CLOSECONTEXTREQUEST
DESCRIPTOR.message_types_by_name['CloseContextResponse'] = _CLOSECONTEXTRESPONSE
DESCRIPTOR.message_types_by_name['RegisterFunctionOp'] = _REGISTERFUNCTIONOP
DESCRIPTOR.message_types_by_name['CleanupFunctionOp'] = _CLEANUPFUNCTIONOP
DESCRIPTOR.message_types_by_name['SyncRemoteExecutorForStream'] = _SYNCREMOTEEXECUTORFORSTREAM
DESCRIPTOR.message_types_by_name['SendTensorOp'] = _SENDTENSOROP
DESCRIPTOR.message_types_by_name['SendPackedHandleOp'] = _SENDPACKEDHANDLEOP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), {'Input': _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {'DESCRIPTOR': _OPERATION_INPUT, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'}), 'AttrsEntry': _reflection.GeneratedProtocolMessageType('AttrsEntry', (_message.Message,), {'DESCRIPTOR': _OPERATION_ATTRSENTRY, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'}), 'DESCRIPTOR': _OPERATION, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(Operation)
_sym_db.RegisterMessage(Operation.Input)
_sym_db.RegisterMessage(Operation.AttrsEntry)
QueueItem = _reflection.GeneratedProtocolMessageType('QueueItem', (_message.Message,), {'DESCRIPTOR': _QUEUEITEM, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(QueueItem)
QueueResponse = _reflection.GeneratedProtocolMessageType('QueueResponse', (_message.Message,), {'DESCRIPTOR': _QUEUERESPONSE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(QueueResponse)
CreateContextRequest = _reflection.GeneratedProtocolMessageType('CreateContextRequest', (_message.Message,), {'DESCRIPTOR': _CREATECONTEXTREQUEST, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(CreateContextRequest)
CreateContextResponse = _reflection.GeneratedProtocolMessageType('CreateContextResponse', (_message.Message,), {'DESCRIPTOR': _CREATECONTEXTRESPONSE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(CreateContextResponse)
UpdateContextRequest = _reflection.GeneratedProtocolMessageType('UpdateContextRequest', (_message.Message,), {'DESCRIPTOR': _UPDATECONTEXTREQUEST, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(UpdateContextRequest)
UpdateContextResponse = _reflection.GeneratedProtocolMessageType('UpdateContextResponse', (_message.Message,), {'DESCRIPTOR': _UPDATECONTEXTRESPONSE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(UpdateContextResponse)
EnqueueRequest = _reflection.GeneratedProtocolMessageType('EnqueueRequest', (_message.Message,), {'DESCRIPTOR': _ENQUEUEREQUEST, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(EnqueueRequest)
EnqueueResponse = _reflection.GeneratedProtocolMessageType('EnqueueResponse', (_message.Message,), {'DESCRIPTOR': _ENQUEUERESPONSE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(EnqueueResponse)
WaitQueueDoneRequest = _reflection.GeneratedProtocolMessageType('WaitQueueDoneRequest', (_message.Message,), {'DESCRIPTOR': _WAITQUEUEDONEREQUEST, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(WaitQueueDoneRequest)
WaitQueueDoneResponse = _reflection.GeneratedProtocolMessageType('WaitQueueDoneResponse', (_message.Message,), {'DESCRIPTOR': _WAITQUEUEDONERESPONSE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(WaitQueueDoneResponse)
RunComponentFunctionRequest = _reflection.GeneratedProtocolMessageType('RunComponentFunctionRequest', (_message.Message,), {'DESCRIPTOR': _RUNCOMPONENTFUNCTIONREQUEST, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(RunComponentFunctionRequest)
RunComponentFunctionResponse = _reflection.GeneratedProtocolMessageType('RunComponentFunctionResponse', (_message.Message,), {'DESCRIPTOR': _RUNCOMPONENTFUNCTIONRESPONSE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(RunComponentFunctionResponse)
KeepAliveRequest = _reflection.GeneratedProtocolMessageType('KeepAliveRequest', (_message.Message,), {'DESCRIPTOR': _KEEPALIVEREQUEST, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(KeepAliveRequest)
KeepAliveResponse = _reflection.GeneratedProtocolMessageType('KeepAliveResponse', (_message.Message,), {'DESCRIPTOR': _KEEPALIVERESPONSE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(KeepAliveResponse)
CloseContextRequest = _reflection.GeneratedProtocolMessageType('CloseContextRequest', (_message.Message,), {'DESCRIPTOR': _CLOSECONTEXTREQUEST, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(CloseContextRequest)
CloseContextResponse = _reflection.GeneratedProtocolMessageType('CloseContextResponse', (_message.Message,), {'DESCRIPTOR': _CLOSECONTEXTRESPONSE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(CloseContextResponse)
RegisterFunctionOp = _reflection.GeneratedProtocolMessageType('RegisterFunctionOp', (_message.Message,), {'DESCRIPTOR': _REGISTERFUNCTIONOP, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(RegisterFunctionOp)
CleanupFunctionOp = _reflection.GeneratedProtocolMessageType('CleanupFunctionOp', (_message.Message,), {'DESCRIPTOR': _CLEANUPFUNCTIONOP, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(CleanupFunctionOp)
SyncRemoteExecutorForStream = _reflection.GeneratedProtocolMessageType('SyncRemoteExecutorForStream', (_message.Message,), {'DESCRIPTOR': _SYNCREMOTEEXECUTORFORSTREAM, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(SyncRemoteExecutorForStream)
SendTensorOp = _reflection.GeneratedProtocolMessageType('SendTensorOp', (_message.Message,), {'DESCRIPTOR': _SENDTENSOROP, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(SendTensorOp)
SendPackedHandleOp = _reflection.GeneratedProtocolMessageType('SendPackedHandleOp', (_message.Message,), {'LocalTensorHandle': _reflection.GeneratedProtocolMessageType('LocalTensorHandle', (_message.Message,), {'DESCRIPTOR': _SENDPACKEDHANDLEOP_LOCALTENSORHANDLE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'}), 'Handle': _reflection.GeneratedProtocolMessageType('Handle', (_message.Message,), {'DESCRIPTOR': _SENDPACKEDHANDLEOP_HANDLE, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'}), 'DESCRIPTOR': _SENDPACKEDHANDLEOP, '__module__': 'tensorflow.core.protobuf.eager_service_pb2'})
_sym_db.RegisterMessage(SendPackedHandleOp)
_sym_db.RegisterMessage(SendPackedHandleOp.LocalTensorHandle)
_sym_db.RegisterMessage(SendPackedHandleOp.Handle)
DESCRIPTOR._options = None
_OPERATION_ATTRSENTRY._options = None
_EAGERSERVICE = _descriptor.ServiceDescriptor(name='EagerService', full_name='tensorflow.eager.EagerService', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=3488, serialized_end=4269, methods=[_descriptor.MethodDescriptor(name='CreateContext', full_name='tensorflow.eager.EagerService.CreateContext', index=0, containing_service=None, input_type=_CREATECONTEXTREQUEST, output_type=_CREATECONTEXTRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='UpdateContext', full_name='tensorflow.eager.EagerService.UpdateContext', index=1, containing_service=None, input_type=_UPDATECONTEXTREQUEST, output_type=_UPDATECONTEXTRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Enqueue', full_name='tensorflow.eager.EagerService.Enqueue', index=2, containing_service=None, input_type=_ENQUEUEREQUEST, output_type=_ENQUEUERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='StreamingEnqueue', full_name='tensorflow.eager.EagerService.StreamingEnqueue', index=3, containing_service=None, input_type=_ENQUEUEREQUEST, output_type=_ENQUEUERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='WaitQueueDone', full_name='tensorflow.eager.EagerService.WaitQueueDone', index=4, containing_service=None, input_type=_WAITQUEUEDONEREQUEST, output_type=_WAITQUEUEDONERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='RunComponentFunction', full_name='tensorflow.eager.EagerService.RunComponentFunction', index=5, containing_service=None, input_type=_RUNCOMPONENTFUNCTIONREQUEST, output_type=_RUNCOMPONENTFUNCTIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='KeepAlive', full_name='tensorflow.eager.EagerService.KeepAlive', index=6, containing_service=None, input_type=_KEEPALIVEREQUEST, output_type=_KEEPALIVERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CloseContext', full_name='tensorflow.eager.EagerService.CloseContext', index=7, containing_service=None, input_type=_CLOSECONTEXTREQUEST, output_type=_CLOSECONTEXTRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_EAGERSERVICE)
DESCRIPTOR.services_by_name['EagerService'] = _EAGERSERVICE




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.python.keras.protobuf import versions_pb2 as tensorflow_dot_python_dot_keras_dot_protobuf_dot_versions__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/python/keras/protobuf/saved_metadata.proto', package='third_party.tensorflow.python.keras.protobuf', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n5tensorflow/python/keras/protobuf/saved_metadata.proto\x12,third_party.tensorflow.python.keras.protobuf\x1a/tensorflow/python/keras/protobuf/versions.proto"Y\n\rSavedMetadata\x12H\n\x05nodes\x18\x01 \x03(\x0b29.third_party.tensorflow.python.keras.protobuf.SavedObject"\xa8\x01\n\x0bSavedObject\x12\x0f\n\x07node_id\x18\x02 \x01(\x05\x12\x11\n\tnode_path\x18\x03 \x01(\t\x12\x12\n\nidentifier\x18\x04 \x01(\t\x12\x10\n\x08metadata\x18\x05 \x01(\t\x12I\n\x07version\x18\x06 \x01(\x0b28.third_party.tensorflow.python.keras.protobuf.VersionDefJ\x04\x08\x01\x10\x02b\x06proto3', dependencies=[tensorflow_dot_python_dot_keras_dot_protobuf_dot_versions__pb2.DESCRIPTOR])
_SAVEDMETADATA = _descriptor.Descriptor(name='SavedMetadata', full_name='third_party.tensorflow.python.keras.protobuf.SavedMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='nodes', full_name='third_party.tensorflow.python.keras.protobuf.SavedMetadata.nodes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=152, serialized_end=241)
_SAVEDOBJECT = _descriptor.Descriptor(name='SavedObject', full_name='third_party.tensorflow.python.keras.protobuf.SavedObject', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node_id', full_name='third_party.tensorflow.python.keras.protobuf.SavedObject.node_id', index=0, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_path', full_name='third_party.tensorflow.python.keras.protobuf.SavedObject.node_path', index=1, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='identifier', full_name='third_party.tensorflow.python.keras.protobuf.SavedObject.identifier', index=2, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='third_party.tensorflow.python.keras.protobuf.SavedObject.metadata', index=3, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='version', full_name='third_party.tensorflow.python.keras.protobuf.SavedObject.version', index=4, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=244, serialized_end=412)
_SAVEDMETADATA.fields_by_name['nodes'].message_type = _SAVEDOBJECT
_SAVEDOBJECT.fields_by_name['version'].message_type = tensorflow_dot_python_dot_keras_dot_protobuf_dot_versions__pb2._VERSIONDEF
DESCRIPTOR.message_types_by_name['SavedMetadata'] = _SAVEDMETADATA
DESCRIPTOR.message_types_by_name['SavedObject'] = _SAVEDOBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
SavedMetadata = _reflection.GeneratedProtocolMessageType('SavedMetadata', (_message.Message,), {'DESCRIPTOR': _SAVEDMETADATA, '__module__': 'tensorflow.python.keras.protobuf.saved_metadata_pb2'})
_sym_db.RegisterMessage(SavedMetadata)
SavedObject = _reflection.GeneratedProtocolMessageType('SavedObject', (_message.Message,), {'DESCRIPTOR': _SAVEDOBJECT, '__module__': 'tensorflow.python.keras.protobuf.saved_metadata_pb2'})
_sym_db.RegisterMessage(SavedObject)
